@@ -4,8 +4,6 @@
 #
 #
 
-from __future__ import annotations
-
 import atexit
 import signal
 import sys
@@ -47,7 +45,7 @@ class Runtime(object):
         signal.signal(signal.SIGINT, safe_hook)
 
     @staticmethod
-    def get_runtime() -> Runtime:
+    def get_runtime() -> "Runtime":
         return runtime
 
 
