@@ -14,6 +14,7 @@ Json = "json"
 
 @spi(Json)
 class JsonCodec(Codec):
+    native_types = (complex, int, float, bool, str, set, tuple, list, iter, bytes, dict)
 
     def encode(self, value: T) -> bytes:
         default = value.encode if value and hasattr(value, 'encode') else None
@@ -27,7 +28,14 @@ class JsonCodec(Codec):
         if vt.__len__() < 1:
             return json.loads(value, cls=kind)
 
-        if issubclass(vt[0], (complex, int, float, bool, str, set, tuple, list, iter, bytes, dict)):
+        if self.is_native_type(vt[0]):
             return json.loads(value)
 
         return json.loads(value, cls=vt[0] if kind else None)
+
+    def is_native_type(self, kind: type) -> bool:
+        for k in self.native_types:
+            if kind is k:
+                return True
+
+        return False
