@@ -8,16 +8,16 @@ from enum import Enum
 
 
 class MeshFlag(Enum):
-    HTTP = "00", "http"
-    GRPC = "01", "grpc"
-    MQTT = "02", "mqtt"
-    TCP = "03", "tcp"
+    HTTP = "00", "http", 0
+    GRPC = "01", "grpc", 0
+    MQTT = "02", "mqtt", 0
+    TCP = "03", "tcp", 0
 
-    JSON = "00", "json"
-    PROTOBUF = "01", "protobuf"
-    XML = "02", "xml"
-    THRIFT = "03", "thrift"
-    YAML = "04", "yaml"
+    JSON = "00", "json", 1
+    PROTOBUF = "01", "protobuf", 1
+    XML = "02", "xml", 1
+    THRIFT = "03", "thrift", 1
+    YAML = "04", "yaml", 1
 
     def get_code(self):
         return self.value[0]
@@ -28,14 +28,14 @@ class MeshFlag(Enum):
     @staticmethod
     def of_proto(code: str) -> "MeshFlag":
         for member in MeshFlag:
-            if member.value and member.value[0] == code:
+            if member.value and member.value[2] == 0 and member.value[0] == code:
                 return member
         return MeshFlag.HTTP
 
     @staticmethod
     def of_code(code: str) -> "MeshFlag":
         for member in MeshFlag:
-            if member.value and member.value[0] == code:
+            if member.value and member.value[2] == 1 and member.value[0] == code:
                 return member
         return MeshFlag.JSON
 
