@@ -31,4 +31,4 @@ class MethodInspector(Inspector):
         return self.method.__annotations__.get("return")
 
     def invoke(self, obj: Any, args: [Any]) -> Any:
-        return self.method(obj, args)
+        return self.method(*args)
