@@ -6,7 +6,7 @@
 
 import inspect
 from concurrent.futures import Future, CancelledError
-from typing import Any, Type, Dict
+from typing import Any, Type, Dict, List
 
 import mesh.log as log
 import mesh.tool as tool
@@ -32,16 +32,17 @@ class ReferenceInvokeHandler(Invoker, InvocationHandler):
     ReferenceInvokeHandler is mesh remote call.
     """
 
-    def __init__(self, macro: mpi, kind: Type[T]):
+    def __init__(self, macro: mpi, kinds: List[Type[T]]):
         inspectors: Dict[Any, Inspector] = {}
-        for interface in kind.__mro__:
-            if not inspect.isabstract(interface):
-                continue
-            for kind, methods in tool.get_declared_methods(interface).items():
-                for method in methods:
-                    inspectors[method] = MethodInspector(macro, interface, method)
+        for kind in kinds:
+            for interface in kind.__mro__:
+                if not inspect.isabstract(interface):
+                    continue
+                for _, methods in tool.get_declared_methods(interface).items():
+                    for method in methods:
+                        inspectors[method] = MethodInspector(macro, interface, method)
         self.macro = macro
-        self.kind = kind
+        self.kinds = kinds
         self.invoker = Filter.composite(self, CONSUMER)
         self.inspectors = inspectors
 
