@@ -6,7 +6,6 @@
 from mesh.system.mesh_builtin import MeshBuiltin
 from mesh.system.mesh_cache import MeshCache
 from mesh.system.mesh_cluster import MeshCluster
-from mesh.system.mesh_configurator import MeshConfigurator
 from mesh.system.mesh_datahouse import MeshDataHouse
 from mesh.system.mesh_dispatcher import MeshDispatcher
 from mesh.system.mesh_endpoint import MeshEndpoint
@@ -24,7 +23,6 @@ __all__ = (
     "MeshBuiltin",
     "MeshCache",
     "MeshCluster",
-    "MeshConfigurator",
     "MeshDataHouse",
     "MeshDispatcher",
     "MeshEndpoint",
